@@ -68,6 +68,7 @@ class Maitai:
         azure_api_key: Optional[str] = None,
         sambanova_api_key: Optional[str] = None,
         gemini_api_key: Optional[str] = None,
+        deepseek_api_key: Optional[str] = None,
         azure_deployment: Optional[str] = None,
         azure_api_version: Optional[str] = None,
         azure_endpoint: Optional[str] = None,
@@ -91,7 +92,7 @@ class Maitai:
             )
         if api_key:
             raise ValueError(
-                "api_key is deprecated. Use provider specific keys instead. Supported variables: openai_api_key, groq_api_key, anthropic_api_key, cerebras_api_key, azure_api_key, sambanova_api_key, gemini_api_key"
+                "api_key is deprecated. Use provider specific keys instead. Supported variables: openai_api_key, groq_api_key, anthropic_api_key, cerebras_api_key, azure_api_key, sambanova_api_key, gemini_api_key, deepseek_api_key"
             )
         if openai_api_key:
             if not config.auth_keys.openai_api_key:
@@ -142,6 +143,13 @@ class Maitai:
                 )
             else:
                 config.auth_keys.gemini_api_key.key_value = gemini_api_key
+        if deepseek_api_key:
+            if not config.auth_keys.deepseek_api_key:
+                config.auth_keys.deepseek_api_key = Key(
+                    key_value=deepseek_api_key,
+                )
+            else:
+                config.auth_keys.deepseek_api_key.key_value = deepseek_api_key
         self._openai_client = None
         self._groq_client = None
         azure_params = None
@@ -482,6 +490,13 @@ class Completions:
                 logger.warning("Maitai issue, retrying on client side")
                 server_side_inference = False
         if not server_side_inference:
+            groq_model = False
+            if "groq:" in model or "maitai:" in model or "llama" in model:
+                groq_model = True
+                model = model.replace("groq:", "").replace("maitai:", "")
+            if "openai:" in model:
+                model = model.replace("openai:", "")
+
             local_params = {
                 "messages": messages,
                 "model": model,
@@ -511,12 +526,6 @@ class Completions:
                 "timeout": timeout,
                 "parallel_tool_calls": parallel_tool_calls,
             }
-            groq_model = False
-            if "groq:" in model or "maitai:" in model or "llama" in model:
-                groq_model = True
-                model = model.replace("groq:", "").replace("maitai:", "")
-            if "openai:" in model:
-                model = model.replace("openai:", "")
 
             if groq_model:
                 if self._groq_client is None:
@@ -690,13 +699,7 @@ class Completions:
                     if chunk.choices and chunk.choices[0].finish_reason:
                         timing.time_request_end = time.time()
                         self.inference.store_request_timing_data(timing)
-                    if chunk.usage:
-                        return
-                    if (
-                        not includes_usage
-                        and chunk.choices
-                        and chunk.choices[0].finish_reason
-                    ):
+                    if chunk.choices and chunk.choices[0].finish_reason:
                         return
         except MaitaiConnectionError as e:
             if "gpt" not in retry_args.get("model", "") and "gpt" in (
