@@ -6,6 +6,7 @@ import uuid
 import warnings
 from typing import AsyncIterable, Dict, Iterable, List, Mapping, Optional, Union
 
+import groq
 import httpx
 import openai
 import openai.types as openai_types
@@ -27,6 +28,7 @@ from maitai._types import (
 from maitai._utils import (
     convert_open_ai_chat_completion_chunk,
     convert_openai_chat_completion,
+    convert_params_to_groq,
     get_chat_completion_params,
     required_args,
     type_to_response_format_param,
@@ -65,6 +67,7 @@ class MaitaiAsync:
         cerebras_api_key: Optional[str] = None,
         sambanova_api_key: Optional[str] = None,
         gemini_api_key: Optional[str] = None,
+        deepseek_api_key: Optional[str] = None,
         azure_api_key: Optional[str] = None,
         azure_deployment: Optional[str] = None,
         azure_api_version: Optional[str] = None,
@@ -135,7 +138,15 @@ class MaitaiAsync:
                 )
             else:
                 config.auth_keys.gemini_api_key.key_value = gemini_api_key
-        self._client = None
+        if deepseek_api_key:
+            if not config.auth_keys.deepseek_api_key:
+                config.auth_keys.deepseek_api_key = Key(
+                    key_value=deepseek_api_key,
+                )
+            else:
+                config.auth_keys.deepseek_api_key.key_value = deepseek_api_key
+        self._openai_client = None
+        self._groq_client = None
         azure_params = None
         if azure_api_key:
             azure_params = AzureParams(
@@ -143,7 +154,7 @@ class MaitaiAsync:
                 deployment=azure_deployment,
                 api_version=azure_api_version,
             )
-            self._client = openai.AsyncAzureOpenAI(
+            self._openai_client = openai.AsyncAzureOpenAI(
                 azure_endpoint=azure_endpoint,
                 azure_deployment=azure_deployment,
                 api_key=azure_api_key,
@@ -159,7 +170,7 @@ class MaitaiAsync:
                 _strict_response_validation=_strict_response_validation,
             )
         elif openai_api_key or os.environ.get("OPENAI_API_KEY"):
-            self._client = openai.AsyncClient(
+            self._openai_client = openai.AsyncClient(
                 api_key=openai_api_key or os.environ.get("OPENAI_API_KEY"),
                 organization=organization,
                 project=project,
@@ -171,6 +182,10 @@ class MaitaiAsync:
                 http_client=http_client,
                 _strict_response_validation=_strict_response_validation,
             )
+        if groq_api_key or config.auth_keys.groq_api_key:
+            self._groq_client = groq.AsyncGroq(
+                api_key=groq_api_key or config.auth_keys.groq_api_key.key_value,
+            )
 
         client_params = None
         if base_url or default_headers or default_query:
@@ -180,25 +195,28 @@ class MaitaiAsync:
                 default_query=default_query or {},
                 azure_params=azure_params,
             )
-        self.chat = AsyncChat(self._client, client_params)
+        self.chat = AsyncChat(self._openai_client, self._groq_client, client_params)
 
 
 class AsyncChat:
     def __init__(
         self,
-        client=None,
+        openai_client=None,
+        groq_client=None,
         client_params: ClientParams = None,
     ):
-        self.completions = AsyncCompletions(client, client_params)
+        self.completions = AsyncCompletions(openai_client, groq_client, client_params)
 
 
 class AsyncCompletions:
     def __init__(
         self,
-        client: Optional[openai.AsyncClient] = None,
+        openai_client: Optional[openai.AsyncClient] = None,
+        groq_client: Optional[groq.AsyncGroq] = None,
         client_params: Optional[ClientParams] = None,
     ):
-        self._client = client
+        self._openai_client = openai_client
+        self._groq_client = groq_client
         self._client_params = client_params or ClientParams()
         self.inference_client = Inference()
         self.evaluator = Evaluator()
@@ -470,47 +488,77 @@ class AsyncCompletions:
                 logger.warning("Maitai issue, retrying on client side")
                 server_side_inference = False
         if not server_side_inference:
+            groq_model = False
+            if "groq:" in model or "maitai:" in model or "llama" in model:
+                groq_model = True
+                model = model.replace("groq:", "").replace("maitai:", "")
             if "openai:" in model:
                 model = model.replace("openai:", "")
-            if self._client is None:
-                self._client = openai.AsyncOpenAI(
-                    default_headers=self._client_params.default_headers or None,
-                    default_query=self._client_params.default_query or None,
-                    base_url=self._client_params.base_url or None,
-                )
+            local_params = {
+                "messages": messages,
+                "model": model,
+                "frequency_penalty": frequency_penalty,
+                "function_call": function_call,
+                "functions": functions,
+                "logit_bias": logit_bias,
+                "logprobs": logprobs,
+                "max_tokens": max_tokens,
+                "n": n,
+                "presence_penalty": presence_penalty,
+                "reasoning_effort": reasoning_effort,
+                "response_format": response_format,
+                "seed": seed,
+                "stop": stop,
+                "stream": stream,
+                "stream_options": stream_options,
+                "temperature": temperature,
+                "tool_choice": tool_choice,
+                "tools": tools,
+                "top_logprobs": top_logprobs,
+                "top_p": top_p,
+                "user": user,
+                "extra_headers": extra_headers,
+                "extra_query": extra_query,
+                "extra_body": extra_body,
+                "timeout": timeout,
+                "parallel_tool_calls": parallel_tool_calls,
+            }
+
+            if groq_model:
+                if self._groq_client is None:
+                    if (
+                        not config.auth_keys.groq_api_key
+                        or not config.auth_keys.groq_api_key.key_value
+                    ):
+                        raise ValueError(
+                            "Groq API key is required for Groq models but was not provided"
+                        )
+
+                    self._groq_client = groq.AsyncGroq(
+                        api_key=config.auth_keys.groq_api_key.key_value,
+                    )
+                client_to_use = self._groq_client
+                local_params = convert_params_to_groq(local_params)
+            else:
+                if self._openai_client is None:
+                    self._openai_client = openai.AsyncOpenAI(
+                        api_key=config.auth_keys.openai_api_key.key_value,
+                        default_headers=self._client_params.default_headers or None,
+                        default_query=self._client_params.default_query or None,
+                        base_url=self._client_params.base_url or None,
+                    )
+                client_to_use = self._openai_client
+
             if hasattr(response_format, "model_json_schema"):
                 response_format = {
                     "type": "json_schema",
                     "json_schema": type_to_response_format_param(response_format),
                 }
-            response = await self._client.chat.completions.create(
-                messages=messages,
-                model=model,
-                frequency_penalty=frequency_penalty,
-                function_call=function_call,
-                functions=functions,
-                logit_bias=logit_bias,
-                logprobs=logprobs,
-                max_tokens=max_tokens,
-                n=n,
-                presence_penalty=presence_penalty,
-                reasoning_effort=reasoning_effort,
-                response_format=response_format,
-                seed=seed,
-                stop=stop,
-                stream=stream,
-                stream_options=stream_options,
-                temperature=temperature,
-                tool_choice=tool_choice,
-                tools=tools,
-                top_logprobs=top_logprobs,
-                top_p=top_p,
-                user=user,
-                extra_headers=extra_headers,
-                extra_query=extra_query,
-                extra_body=extra_body,
-                timeout=timeout,
-                parallel_tool_calls=parallel_tool_calls,
+            if isinstance(tools, Tools):
+                tools = tools.get_tool_definitions()
+
+            response = await client_to_use.chat.completions.create(
+                **local_params,
             )
             if stream:
                 return self._process_async_openai_stream(
@@ -654,13 +702,7 @@ class AsyncCompletions:
                         asyncio.create_task(
                             self.inference_client.send_request_timing_data_async(timing)
                         )
-                    if chunk.usage:
-                        return
-                    if (
-                        not includes_usage
-                        and chunk.choices
-                        and chunk.choices[0].finish_reason
-                    ):
+                    if chunk.choices and chunk.choices[0].finish_reason:
                         return
         except MaitaiConnectionError as e:
             if "gpt" not in retry_args.get("model", "") and "gpt" in (
