@@ -43,30 +43,6 @@ def _get_aws_instance_metadata(url, timeout=2):
         return None
 
 
-def _get_gcp_instance_metadata(url, timeout=2):
-    try:
-        headers = {"Metadata-Flavor": "Google"}
-        with httpx.Client() as client:
-            response = client.get(url, headers=headers, timeout=timeout)
-            response.raise_for_status()
-            return response.text
-    except Exception:
-        return None
-
-
-def _get_azure_instance_metadata(timeout=2):
-    try:
-        headers = {"Metadata": "true"}
-        url = "http://169.254.169.254/metadata/instance/compute?api-version=2021-02-01"
-        with httpx.Client() as client:
-            response = client.get(url, headers=headers, timeout=timeout)
-            response.raise_for_status()
-            data = response.json()
-            return data.get("location")
-    except Exception:
-        return None
-
-
 def _determine_maitai_host():
     if maitai_host := os.environ.get("MAITAI_HOST"):
         return maitai_host.rstrip("/")
@@ -79,21 +55,6 @@ def _determine_maitai_host():
     ):
         return "https://api.aws.us-west-2.trymaitai.ai"
 
-    gcp_zone = _get_gcp_instance_metadata(
-        "http://metadata.google.internal/computeMetadata/v1/instance/zone"
-    )
-    if gcp_zone:
-        if "us-west1" in gcp_zone:
-            return "https://api.gcp.us-west1.trymaitai.ai"
-        # elif "us-central1" in gcp_zone:
-        #     return "https://api.gcp.us-central1.trymaitai.ai"
-        elif "us-south1" in gcp_zone:
-            return "https://api.gcp.us-south1.trymaitai.ai"
-
-    azure_region = _get_azure_instance_metadata()
-    if azure_region == "westus2":
-        return "https://api.azure.westus2.trymaitai.ai"
-
     return "https://api.trymaitai.ai"
 
 
@@ -109,7 +70,7 @@ class MaitaiClient:
         if self._client is None:
             self._client = httpx.Client(
                 **CLIENT_SETTINGS,
-                transport=httpx.HTTPTransport(retries=DEFAULT_MAX_RETRIES),
+                transport=httpx.HTTPTransport(retries=DEFAULT_MAX_RETRIES, http2=True),
             )
         return self._client
 
@@ -117,7 +78,9 @@ class MaitaiClient:
         if self._async_client is None:
             self._async_client = httpx.AsyncClient(
                 **CLIENT_SETTINGS,
-                transport=httpx.AsyncHTTPTransport(retries=DEFAULT_MAX_RETRIES),
+                transport=httpx.AsyncHTTPTransport(
+                    retries=DEFAULT_MAX_RETRIES, http2=True
+                ),
             )
         return self._async_client
 
@@ -149,6 +112,8 @@ class MaitaiClient:
 
     def _log_error(self, api_key: str, error: str, path: str):
         host = self.maitai_host
+        if "/batch" in host:
+            host = host.replace("/batch", "")
         url = f"{host}/metrics/increment/python_sdk_error"
         headers = {
             "Content-Type": "application/json",
@@ -168,6 +133,8 @@ class MaitaiClient:
 
     async def log_error_async(self, api_key: str, error: str, path: str):
         host = self.maitai_host
+        if "/batch" in host:
+            host = host.replace("/batch", "")
         url = f"{host}/metrics/increment/python_sdk_error"
         headers = {
             "Content-Type": "application/json",
@@ -187,6 +154,8 @@ class MaitaiClient:
 
     def init_sdk(self, api_key: str, host: str):
         """Initialize the SDK and warm up connections."""
+        if "/batch" in host:
+            host = host.replace("/batch", "")
         url = f"{host}/config/init_sdk"
         headers = {
             "Content-Type": "application/json",
