@@ -5,6 +5,7 @@ from enum import Enum, IntEnum
 from typing import Any, Dict, List, Optional, Union
 
 from pydantic import BaseModel, ConfigDict, Field
+from typing_extensions import Literal
 
 from maitai.models import application as application_types
 from maitai.models import config, key, metric, sentinel
@@ -16,6 +17,9 @@ class EvaluationProvider(Enum):
     CEREBRAS = 2
     MAITAI = 3
     SAMBANOVA = 4
+    GEMINI = 5
+    DEEPSEEK = 6
+    ANTHROPIC = 7
 
 
 class AzureParams(BaseModel):
@@ -39,6 +43,8 @@ class ChatCompletionAuth(BaseModel):
     cerebras_api_key: Optional[str] = ""
     azure_api_key: Optional[str] = ""
     sambanova_api_key: Optional[str] = ""
+    gemini_api_key: Optional[str] = ""
+    deepseek_api_key: Optional[str] = ""
 
 
 class Property(BaseModel):
@@ -46,6 +52,7 @@ class Property(BaseModel):
     description: Optional[str] = None
     items: Optional["FunctionParameters"] = None
     anyOf: Optional[List["Property"]] = None
+    enum: List[str] = Field(default_factory=list)
 
     def model_dump(self, **kwargs):
         kwargs.setdefault("exclude_none", True)
@@ -78,7 +85,7 @@ class Tool(BaseModel):
 
 
 class JSONSchema(BaseModel):
-    name: str
+    name: str = "output_schema"
     strict: Optional[bool] = False
     json_schema: FunctionParameters = Field(alias="schema")
 
@@ -174,6 +181,7 @@ class ChatCompletionRequest(BaseModel):
     safe_mode: Optional[bool] = Field(default=False)
     preserve_model_alias: Optional[bool] = False
     fallback_config: Optional[config.FallbackConfig] = None
+    request_type: Literal["PROD", "RERUN", "SYNTHETIC"] = "PROD"
 
 
 class FunctionCall(BaseModel):
@@ -266,7 +274,7 @@ class EvaluateResponse(BaseModel):
 class ChatCompletionResponse(BaseModel):
     id: Optional[Union[int, str]] = None
     object: str = "chat.completion"
-    created: float = Field(default_factory=time.time)
+    created: Union[int, float] = Field(default_factory=lambda: int(time.time()))
     model: str = None
     system_fingerprint: Optional[str] = None
     choices: List[ChatCompletionChoice] = Field(default_factory=list)
@@ -317,7 +325,7 @@ class ChunkChoice(BaseModel):
 class ChatCompletionChunk(BaseModel):
     id: str = ""
     choices: List[ChunkChoice] = Field(default_factory=list)
-    created: float = Field(default_factory=time.time)
+    created: int = Field(default_factory=lambda: int(time.time()))
     model: str = ""
     object: str = ""
     system_fingerprint: Optional[str] = ""
